==> eslint-2.8.0.tgz: package/lib/rules/no-case-declarations.js <==
/**
 * @fileoverview Rule to flag use of an lexical declarations inside a case clause
 * @author Erik Arvidsson
 * @copyright 2015 Erik Arvidsson. All rights reserved.
 */
"use strict";

//------------------------------------------------------------------------------
// Rule Definition
//------------------------------------------------------------------------------

module.exports = {
    meta: {
        docs: {
            description: "disallow lexical declarations in case clauses",
            category: "Best Practices",
            recommended: true
        },

        schema: []
    },

    create: function(context) {

        /**
         * Checks whether or not a node is a lexical declaration.
         * @param {ASTNode} node A direct child statement of a switch case.
         * @returns {boolean} Whether or not the node is a lexical declaration.
         */
        function isLexicalDeclaration(node) {
            switch (node.type) {
                case "FunctionDeclaration":
                case "ClassDeclaration":
                    return true;
                case "VariableDeclaration":
                    return node.kind !== "var";
                default:
                    return false;
            }
        }

        return {
            "SwitchCase": function(node) {
                for (var i = 0; i < node.consequent.length; i++) {
                    var statement = node.consequent[i];

                    if (isLexicalDeclaration(statement)) {
                        context.report({
                            node: node,
                            message: "Unexpected lexical declaration in case block."
                        });
                    }
                }
            }
        };

    }
};

==> eslint-3.2.2.tgz: package/lib/rules/no-case-declarations.js <==
/**
 * @fileoverview Rule to flag use of an lexical declarations inside a case clause
 * @author Erik Arvidsson
 */
"use strict";

//------------------------------------------------------------------------------
// Rule Definition
//------------------------------------------------------------------------------

module.exports = {
    meta: {
        docs: {
            description: "disallow lexical declarations in case clauses",
            category: "Best Practices",
            recommended: true
        },

        schema: []
    },

    create: function(context) {

        /**
         * Checks whether or not a node is a lexical declaration.
         * @param {ASTNode} node A direct child statement of a switch case.
         * @returns {boolean} Whether or not the node is a lexical declaration.
         */
        function isLexicalDeclaration(node) {
            switch (node.type) {
                case "FunctionDeclaration":
                case "ClassDeclaration":
                    return true;
                case "VariableDeclaration":
                    return node.kind !== "var";
                default:
                    return false;
            }
        }

        return {
            SwitchCase: function(node) {
                for (let i = 0; i < node.consequent.length; i++) {
                    let statement = node.consequent[i];

                    if (isLexicalDeclaration(statement)) {
                        context.report({
                            node: node,
                            message: "Unexpected lexical declaration in case block."
                        });
                    }
                }
            }
        };

    }
};
